@@ -1,5 +1,6 @@
 import json
 import datetime
+import logging
 import random
 import string
 import hashlib
@@ -195,5 +196,9 @@ def run(f, *args, onerror=None, onsuccess=None, **kwargs):
         return ret
     except Exception as e:
         if callable(onerror):
-            return onsuccess(e)
+            return onerror(e)
         raise e
+
+
+def base_error_cb(e=None, exc=None, logger=None):
+    (logger or logging).error(e or exc or 'error')
